aboutsummaryrefslogtreecommitdiff
path: root/src/vendorcode/amd
diff options
context:
space:
mode:
Diffstat (limited to 'src/vendorcode/amd')
-rw-r--r--src/vendorcode/amd/fsp/picasso/platform_descriptors.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/vendorcode/amd/fsp/picasso/platform_descriptors.h b/src/vendorcode/amd/fsp/picasso/platform_descriptors.h
index acf821b6e2..2faa0abe97 100644
--- a/src/vendorcode/amd/fsp/picasso/platform_descriptors.h
+++ b/src/vendorcode/amd/fsp/picasso/platform_descriptors.h
@@ -109,8 +109,11 @@ typedef struct __packed {
uint8_t reserved;
} fsp_ddi_descriptor;
/* Picasso PCIe Descriptor: used for assigning lanes, bifurcation and other settings */
/* Beware that the lane numbers in here are the logical and not the physical lane numbers! */
typedef struct __packed {
uint8_t engine_type;
uint8_t start_logical_lane; // Start lane of the pci device
@@ -138,6 +141,6 @@ typedef struct __packed {
uint32_t channel_type :3;
uint32_t turn_off_unused_lanes :1;
uint8_t reserved[4];
-} fsp_pcie_descriptor;
+} fsp_dxio_descriptor;
#endif /* __PI_PICASSO_PLATFORM_DESCRIPTORS_H__ */
@@ -109,8 +109,11 @@ typedef struct __packed {
uint8_t reserved;
} fsp_ddi_descriptor;
-/* Picasso PCIe Descriptor: used for assigning lanes, bifurcation and other settings */
-/* Beware that the lane numbers in here are the logical and not the physical lane numbers! */
+/*
+ * Picasso DXIO Descriptor: Used for assigning lanes to PCIe/SATA/XGBE engines, configure
+ * bifurcation and other settings. Beware that the lane numbers in here are the logical and not
+ * the physical lane numbers!
+ */
typedef struct __packed {
uint8_t engine_type;